[−][src]Enum rusoto_machinelearning::CreateBatchPredictionError
Errors returned by CreateBatchPrediction
Variants
IdempotentParameterMismatch(String)A second request to use or change an object was not allowed. This can result from retrying a request using a parameter that was not present in the original request.
InternalServer(String)An error on the server occurred when trying to process a request.
InvalidInput(String)An error on the client occurred. Typically, the cause is an invalid input value.
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl CreateBatchPredictionError[src]
pub fn from_response(res: BufferedHttpResponse) -> CreateBatchPredictionError[src]